.console{position:absolute;top:52px;right:0;bottom:0;left:70px;width:auto;overflow-x:auto;overflow-y:hidden}.console .col,.console .col-15,.console .col-85{position:relative;width:100%;height:100%;float:left}.console .col-15{width:15%}.console .col-85{width:85%}.console .load-indicator{position:fixed;top:52px;left:70px;padding-right:70px;width:100%;height:100%;z-index:900;background-color:#fff;display:table}.console .load-indicator .spinner{display:table-cell;vertical-align:middle;text-align:center}.console .load-indicator .spinner p{font-weight:300;margin-top:10px}.console .header{position:relative;z-index:1;width:100%;height:100px;line-height:100px;margin-bottom:10px;vertical-align:middle}.console .header .header-content{height:100%;overflow:hidden}.console .header .header-content input{display:inline-block;line-height:20px;width:90%;margin-left:5%;margin-right:5%}.console .header .header-content .buttons{position:absolute;bottom:10px;left:0;height:10px;line-height:10px;width:90%;margin-left:5%;margin-right:5%}.console .header .header-content .buttons .fa{cursor:pointer;margin-right:10px}.console .header .header-content .builders{position:relative;height:100%;background:#fff;padding-right:30px}.console .header .header-content .builders .builder{position:relative;float:left;height:100%;text-align:center;vertical-align:middle;margin-top:30px;-webkit-transform:translateX(5px) rotate(-60deg);-moz-transform:translateX(5px) rotate(-60deg);-ms-transform:translateX(5px) rotate(-60deg);-o-transform:translateX(5px) rotate(-60deg);transform:translateX(5px) rotate(-60deg);text-decoration:none;white-space:nowrap}.console .content{position:relative;width:100%;height:100%}.console .content .change-rows{position:absolute;top:0;bottom:110px;overflow-y:auto;overflow-x:visible}.console .content .change-rows .change-row{width:100%;height:30px;padding-right:30px;border-top-style:dotted;border-top-width:thin;border-top-color:#000}.console .content .change-rows .change-row .name{width:90%;padding-left:5%;padding-right:5%;margin:5px 0;white-space:nowrap;overflow:hidden}.console .content .change-rows .change-row .fa{margin-right:10px}.console .content .change-rows .change-row .fa.fa-chevron-circle-right{cursor:pointer;transition:.5s all ease;-webkit-transition:.5s all ease}.console .content .change-rows .change-row .info-collapse{height:initial;padding-left:35px}.console .content .change-rows .change-row .info-collapse .panel{margin-top:15px}.console .content .change-rows .change-row .info{width:100%}.console .content .change-rows .change-row .info .fa{float:left;line-height:25px}.console .content .change-rows .change-row .info p{padding-left:22px;white-space:pre-wrap}.console .content .change-rows .change-row .builds{position:relative;height:100%}.console .content .change-rows .change-row .builds .build{position:relative;float:left;height:100%;text-align:center;vertical-align:middle;text-decoration:none}.console .content .change-rows .change-row .builds .build .badge-status{cursor:pointer}.modal-small .modal-dialog{width:500px}.modal-small .fa{cursor:pointer}